Dallinger
=========

|Build Status| |Demos| |codecov| |Code Climate| |License|

Laboratory automation for the behavioral and social sciences.

Features
--------

-  Performs laboratory automation for the behavioral and social sciences
-  Coordinates participant recruitment using Mechanical Turk

Install
-------

To install Dallinger, see `the
instructions <http://dallinger.readthedocs.io/>`__.

Documentation
-------------

Documentation is available on the `documentation
website <http://dallinger.readthedocs.io/>`__.

Demos
-----

Demonstration experiments are distributed separately in the
``dlgr.demos`` package.

Contribute
----------

-  Issue Tracker: http://github.com/Dallinger/Dallinger/issues
-  Source Code: http://github.com/Dallinger/Dallinger

Support
-------

If you are having issues, please `let us
know <http://github.com/Dallinger/Dallinger/issues>`__. We run a users
group at https://groups.google.com/d/forum/dallinger.

License
-------

The project is licensed under the MIT license.

.. |Build Status| image:: https://github.com/dallinger/Dallinger/workflows/continuous-integration/badge.svg
   :target: https://github.com/Dallinger/Dallinger/actions?query=workflow%3Acontinuous-integration
.. |Demos| image:: https://img.shields.io/badge/demos-11-edd172.svg
   :target: http://dallinger.readthedocs.io/en/latest/#demos
.. |codecov| image:: https://codecov.io/gh/Dallinger/Dallinger/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/Dallinger/Dallinger
.. |Code Climate| image:: https://codeclimate.com/github/Dallinger/Dallinger/badges/gpa.svg
   :target: https://codeclimate.com/github/Dallinger/Dallinger
.. |License| image:: https://img.shields.io/badge/license-MIT-blue.svg
   :target: http://en.wikipedia.org/wiki/MIT_License
